package io.github.wulkanowy.ui.modules.settings

import android.content.SharedPreferences
import android.os.Bundle
import android.view.View
import androidx.preference.Preference
import androidx.preference.PreferenceFragmentCompat
import androidx.preference.PreferenceScreen
import dagger.hilt.android.AndroidEntryPoint
import io.github.wulkanowy.R
import io.github.wulkanowy.data.repositories.PreferencesRepository
import io.github.wulkanowy.ui.modules.main.MainView
import timber.log.Timber
import javax.inject.Inject

@AndroidEntryPoint
class SettingsFragment : PreferenceFragmentCompat(),
    SharedPreferences.OnSharedPreferenceChangeListener,
    MainView.TitledView, SettingsView {

    companion object {

        fun newInstance() = SettingsFragment()
    }

    override val titleStringId get() = R.string.settings_title

    @Inject
    lateinit var preferencesRepository: PreferencesRepository

    override fun onCreatePreferences(savedInstanceState: Bundle?, rootKey: String?) {
        setPreferencesFromResource(R.xml.scheme_preferences, rootKey)

        val prefScreen: PreferenceScreen? = findPreference("settings_preferences")
        val prefDeveloper: Preference? = findPreference("mod_settings")

        if (!preferencesRepository.developerMode && prefScreen != null && prefDeveloper != null) {
            prefScreen.removePreference(prefDeveloper)
        }

        Timber.i("Settings view was initialized")
    }

    override fun onSharedPreferenceChanged(sharedPreferences: SharedPreferences?, rootKey: String?) {
        setPreferencesFromResource(R.xml.scheme_preferences, rootKey)
    }

    override fun showError(text: String, error: Throwable) {}

    override fun showMessage(text: String) {}

    override fun showExpiredCredentialsDialog() {}

    override fun onCaptchaVerificationRequired(url: String?) = Unit

    override fun showDecryptionFailedDialog() {}

    override fun openClearLoginView() {}

    override fun showErrorDetailsDialog(error: Throwable) {}

    override fun showChangePasswordSnackbar(redirectUrl: String) {}

    override fun showAuthDialog() {}
}
